pygeodesy.deprecated.bases.LatLonHeightBase

Package pygeodesy :: Package deprecated :: Module bases :: Class LatLonHeightBase |
[frames] | no frames]

# Class LatLonHeightBase

           object --+
                    |
         named._Named --+
                        |
         named._NamedBase --+
                            |
           object --+       |
                    |       |
         named._Named --+   |
                        |   |
    ecefLocals._EcefLocal --+
                            |
        latlonBase.LatLonBase --+
                                |
                               LatLonHeightBase

DEPRECATED on 2021.02.10, use (INTERNAL) class pygeodesy.latlonBase.LatLonBase.

Instance Methods
Inherited from `latlonBase.LatLonBase`: `PointsIter`, `__eq__`, `__init__`, `__ne__`, `__str__`, `antipode`, `bounds`, `boundsOf`, `chordTo`, `circin6`, `circum3`, `circum4_`, `compassAngle`, `compassAngleTo`, `cosineAndoyerLambertTo`, `cosineForsytheAndoyerLambertTo`, `cosineLawTo`, `destinationXyz`, `equals`, `equals3`, `equirectangularTo`, `euclideanTo`, `flatLocalTo`, `flatPolarTo`, `hartzell`, `haversineTo`, `height4`, `heightStr`, `hubenyTo`, `intersecant2`, `isantipode`, `isantipodeTo`, `isequalTo`, `isequalTo3`, `latlon2`, `latlon2round`, `latlon_`, `nearestOn6`, `nearestTo`, `normal`, `philam2`, `points`, `points2`, `radii11`, `rhumbAzimuthTo`, `rhumbDestination`, `rhumbDistanceTo`, `rhumbIntersecant2`, `rhumbLine`, `rhumbMidpointTo`, `thomasTo`, `to2ab`, `to3llh`, `to3xyz`, `toCartesian`, `toDatum`, `toEcef`, `toNormal`, `toNvector`, `toStr`, `toVector`, `toVector3d`, `toWm`, `vincentysTo` Inherited from `named._NamedBase`: `__repr__`, `others`, `toRepr` Inherited from `ecefLocals._EcefLocal`: `toAer`, `toEnu`, `toLocal`, `toLtp`, `toNed`, `toXyz` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
Inherited from `latlonBase.LatLonBase`: `clipid`, `datum`, `ellipsoidalLatLon`, `height`, `isEllipsoidal`, `isSpherical`, `isnormal`, `lam`, `lat`, `latlon`, `latlonheight`, `lon`, `phi`, `philam`, `philamheight`, `sphericalLatLon`, `xyz`, `xyz3`, `xyzh` Inherited from `ecefLocals._EcefLocal`: `Ecef` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`